/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KScreen.Backend.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef BACKENDADAPTOR_H
#define BACKENDADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "backenddbuswrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kscreen.Backend
 */
class BackendAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kscreen.Backend")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kscreen.Backend\">\n"
"    <method name=\"getConfig\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"setConfig\">\n"
"      <arg direction=\"in\" type=\"a{sv}\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <signal name=\"configChanged\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <method name=\"getEdid\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"      <arg direction=\"out\" type=\"ay\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    BackendAdaptor(BackendDBusWrapper *parent);
    ~BackendAdaptor() override;

    inline BackendDBusWrapper *parent() const
    { return static_cast<BackendDBusWrapper *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QVariantMap getConfig();
    QByteArray getEdid(int in0);
    QVariantMap setConfig(const QVariantMap &in0);
Q_SIGNALS: // SIGNALS
    void configChanged(const QVariantMap &in0);
};

#endif
