/****************************************************************************
** Meta object code from reading C++ file 'xrandr.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libkscreen-6.7.4/backends/xrandr/xrandr.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xrandr.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6XRandRE_t {};
} // unnamed namespace

template <> constexpr inline auto XRandR::qt_create_metaobjectdata<qt_meta_tag_ZN6XRandRE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XRandR"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XRandR, qt_meta_tag_ZN6XRandRE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XRandR::staticMetaObject = { {
    QMetaObject::SuperData::link<KScreen::AbstractBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6XRandRE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6XRandRE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6XRandRE_t>.metaTypes,
    nullptr
} };

void XRandR::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XRandR *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XRandR::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XRandR::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6XRandRE_t>.strings))
        return static_cast<void*>(this);
    return KScreen::AbstractBackend::qt_metacast(_clname);
}

int XRandR::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KScreen::AbstractBackend::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_XRandR[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1f,  'o',  'r',  'g',  '.',  'k', 
    'f',  '6',  '.',  'k',  's',  'c',  'r',  'e', 
    'e',  'n',  '.',  'b',  'a',  'c',  'k',  'e', 
    'n',  'd',  's',  '.',  'x',  'r',  'a',  'n', 
    'd',  'r', 
    // "className"
    0x03,  0x66,  'X',  'R',  'a',  'n',  'd',  'R', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(XRandR, XRandR, qt_pluginMetaDataV2_XRandR)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_XRandR[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1f,  'o',  'r',  'g',  '.',  'k', 
    'f',  '6',  '.',  'k',  's',  'c',  'r',  'e', 
    'e',  'n',  '.',  'b',  'a',  'c',  'k',  'e', 
    'n',  'd',  's',  '.',  'x',  'r',  'a',  'n', 
    'd',  'r', 
    // "className"
    0x03,  0x66,  'X',  'R',  'a',  'n',  'd',  'R', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(XRandR, XRandR)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
