/****************************************************************************
** Meta object code from reading C++ file 'fakebackendadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "fakebackendadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fakebackendadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18FakeBackendAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FakeBackendAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18FakeBackendAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FakeBackendAdaptor",
        "D-Bus Interface",
        "org.kde.kscreen.FakeBackend",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kscreen.FakeBackend\">\n    <method na"
        "me=\"setConnected\">\n      <arg direction=\"in\" type=\"i\" name="
        "\"outputId\"/>\n      <arg direction=\"in\" type=\"b\" name=\"conn"
        "ected\"/>\n    </method>\n    <method name=\"setEnabled\">\n      "
        "<arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n      <arg d"
        "irection=\"in\" type=\"b\" name=\"enabled\"/>\n    </method>\n    "
        "<method name=\"setCurrentModeId\">\n      <arg direction=\"in\" ty"
        "pe=\"i\" name=\"outputId\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"currentModeId\"/>\n    </method>\n    <method name=\"set"
        "Rotation\">\n      <arg direction=\"in\" type=\"i\" name=\"outputI"
        "d\"/>\n      <arg direction=\"in\" type=\"i\" name=\"rotation\"/>\n"
        "    </method>\n    <method name=\"addOutput\">\n      <arg directi"
        "on=\"in\" type=\"i\" name=\"outputId\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"name\"/>\n    </method>\n    <method name=\""
        "removeOutput\">\n      <arg direction=\"in\" type=\"i\" name=\"out"
        "putId\"/>\n    </method>\n  </interface>\n",
        "addOutput",
        "",
        "outputId",
        "name",
        "removeOutput",
        "setConnected",
        "connected",
        "setCurrentModeId",
        "currentModeId",
        "setEnabled",
        "enabled",
        "setRotation",
        "rotation"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addOutput'
        QtMocHelpers::SlotData<void(int, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'removeOutput'
        QtMocHelpers::SlotData<void(int)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setConnected'
        QtMocHelpers::SlotData<void(int, bool)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'setCurrentModeId'
        QtMocHelpers::SlotData<void(int, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void(int, int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FakeBackendAdaptor, qt_meta_tag_ZN18FakeBackendAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FakeBackendAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FakeBackendAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FakeBackendAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18FakeBackendAdaptorE_t>.metaTypes,
    nullptr
} };

void FakeBackendAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeBackendAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addOutput((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->removeOutput((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->setConnected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->setCurrentModeId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->setRotation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *FakeBackendAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FakeBackendAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FakeBackendAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FakeBackendAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
