/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KScreen.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "backendloaderadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class BackendLoaderAdaptor
 */

BackendLoaderAdaptor::BackendLoaderAdaptor(BackendLoader *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

BackendLoaderAdaptor::~BackendLoaderAdaptor()
{
    // destructor
}

QString BackendLoaderAdaptor::backend()
{
    // handle method call org.kde.KScreen.backend
    return parent()->backend();
}

void BackendLoaderAdaptor::quit()
{
    // handle method call org.kde.KScreen.quit
    parent()->quit();
}

bool BackendLoaderAdaptor::requestBackend(const QString &in0, const QVariantMap &in1)
{
    // handle method call org.kde.KScreen.requestBackend
    return parent()->requestBackend(in0, in1);
}


#include "moc_backendloaderadaptor.cpp"
