/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KScreen.Backend.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "backendadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class BackendAdaptor
 */

BackendAdaptor::BackendAdaptor(BackendDBusWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

BackendAdaptor::~BackendAdaptor()
{
    // destructor
}

QVariantMap BackendAdaptor::getConfig()
{
    // handle method call org.kde.kscreen.Backend.getConfig
    return parent()->getConfig();
}

QByteArray BackendAdaptor::getEdid(int in0)
{
    // handle method call org.kde.kscreen.Backend.getEdid
    return parent()->getEdid(in0);
}

QVariantMap BackendAdaptor::setConfig(const QVariantMap &in0)
{
    // handle method call org.kde.kscreen.Backend.setConfig
    return parent()->setConfig(in0);
}


#include "moc_backendadaptor.cpp"
