/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KScreen.FakeBackend.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "fakebackendadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FakeBackendAdaptor
 */

FakeBackendAdaptor::FakeBackendAdaptor(Fake *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FakeBackendAdaptor::~FakeBackendAdaptor()
{
    // destructor
}

void FakeBackendAdaptor::addOutput(int outputId, const QString &name)
{
    // handle method call org.kde.kscreen.FakeBackend.addOutput
    parent()->addOutput(outputId, name);
}

void FakeBackendAdaptor::removeOutput(int outputId)
{
    // handle method call org.kde.kscreen.FakeBackend.removeOutput
    parent()->removeOutput(outputId);
}

void FakeBackendAdaptor::setConnected(int outputId, bool connected)
{
    // handle method call org.kde.kscreen.FakeBackend.setConnected
    parent()->setConnected(outputId, connected);
}

void FakeBackendAdaptor::setCurrentModeId(int outputId, const QString &currentModeId)
{
    // handle method call org.kde.kscreen.FakeBackend.setCurrentModeId
    parent()->setCurrentModeId(outputId, currentModeId);
}

void FakeBackendAdaptor::setEnabled(int outputId, bool enabled)
{
    // handle method call org.kde.kscreen.FakeBackend.setEnabled
    parent()->setEnabled(outputId, enabled);
}

void FakeBackendAdaptor::setRotation(int outputId, int rotation)
{
    // handle method call org.kde.kscreen.FakeBackend.setRotation
    parent()->setRotation(outputId, rotation);
}


#include "moc_fakebackendadaptor.cpp"
