/****************************************************************************
** Meta object code from reading C++ file 'backendadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "backendadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'backendadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14BackendAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto BackendAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14BackendAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BackendAdaptor",
        "D-Bus Interface",
        "org.kde.kscreen.Backend",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kscreen.Backend\">\n    <method name=\""
        "getConfig\">\n      <arg direction=\"out\" type=\"a{sv}\"/>\n     "
        " <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtT"
        "ypeName.Out0\"/>\n    </method>\n    <method name=\"setConfig\">\n"
        "      <arg direction=\"in\" type=\"a{sv}\"/>\n      <arg direction"
        "=\"out\" type=\"a{sv}\"/>\n      <annotation value=\"QVariantMap\""
        " name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotation"
        " value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0"
        "\"/>\n    </method>\n    <signal name=\"configChanged\">\n      <a"
        "rg direction=\"out\" type=\"a{sv}\"/>\n      <annotation value=\"Q"
        "VariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    "
        "</signal>\n    <method name=\"getEdid\">\n      <arg direction=\"i"
        "n\" type=\"i\"/>\n      <arg direction=\"out\" type=\"ay\"/>\n    "
        "</method>\n  </interface>\n",
        "configChanged",
        "",
        "QVariantMap",
        "in0",
        "getConfig",
        "getEdid",
        "setConfig"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'getConfig'
        QtMocHelpers::SlotData<QVariantMap()>(9, 6, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'getEdid'
        QtMocHelpers::SlotData<QByteArray(int)>(10, 6, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setConfig'
        QtMocHelpers::SlotData<QVariantMap(const QVariantMap &)>(11, 6, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BackendAdaptor, qt_meta_tag_ZN14BackendAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BackendAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BackendAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BackendAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14BackendAdaptorE_t>.metaTypes,
    nullptr
} };

void BackendAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BackendAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: { QVariantMap _r = _t->getConfig();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: { QByteArray _r = _t->getEdid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantMap _r = _t->setConfig((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BackendAdaptor::*)(const QVariantMap & )>(_a, &BackendAdaptor::configChanged, 0))
            return;
    }
}

const QMetaObject *BackendAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BackendAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BackendAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int BackendAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void BackendAdaptor::configChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
