/****************************************************************************
** Meta object code from reading C++ file 'edid.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkscreen-6.7.4/src/edid.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'edid.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KScreen4EdidE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::Edid::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen4EdidE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::Edid",
        "deviceId",
        "name",
        "vendor",
        "serial",
        "eisaId",
        "hash",
        "width",
        "height",
        "gamma",
        "red",
        "QQuaternion",
        "green",
        "blue",
        "white",
        "rawData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'deviceId'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'vendor'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serial'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'eisaId'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hash'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'width'
        QtMocHelpers::PropertyData<uint>(7, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<uint>(8, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gamma'
        QtMocHelpers::PropertyData<qreal>(9, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'red'
        QtMocHelpers::PropertyData<QQuaternion>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'green'
        QtMocHelpers::PropertyData<QQuaternion>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'blue'
        QtMocHelpers::PropertyData<QQuaternion>(13, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'white'
        QtMocHelpers::PropertyData<QQuaternion>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'rawData'
        QtMocHelpers::PropertyData<QByteArray>(15, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Edid, qt_meta_tag_ZN7KScreen4EdidE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreen::Edid::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4EdidE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4EdidE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen4EdidE_t>.metaTypes,
    nullptr
} };

void KScreen::Edid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Edid *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->deviceId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->serial(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->eisaId(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->hash(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->width(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->height(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->gamma(); break;
        case 9: *reinterpret_cast<QQuaternion*>(_v) = _t->red(); break;
        case 10: *reinterpret_cast<QQuaternion*>(_v) = _t->green(); break;
        case 11: *reinterpret_cast<QQuaternion*>(_v) = _t->blue(); break;
        case 12: *reinterpret_cast<QQuaternion*>(_v) = _t->white(); break;
        case 13: *reinterpret_cast<QByteArray*>(_v) = _t->rawData(); break;
        default: break;
        }
    }
}

const QMetaObject *KScreen::Edid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Edid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4EdidE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Edid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
