// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kscreen_backendLauncher_debug.h"


Q_LOGGING_CATEGORY(KSCREEN_BACKEND_LAUNCHER, "org.kde.kscreen.backendLauncher", QtInfoMsg)

