/****************************************************************************
** Meta object code from reading C++ file 'config.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkscreen-6.7.4/src/config.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KScreen6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::Config::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::Config",
        "outputAdded",
        "",
        "KScreen::OutputPtr",
        "output",
        "outputRemoved",
        "outputId",
        "prioritiesChanged",
        "screen",
        "ScreenPtr",
        "outputs",
        "OutputList",
        "ValidityFlag",
        "None",
        "RequireAtLeastOneEnabledScreen",
        "Feature",
        "PrimaryDisplay",
        "Writable",
        "PerOutputScaling",
        "OutputReplication",
        "AutoRotation",
        "TabletMode",
        "SynchronousOutputChanges",
        "XwaylandScales"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'outputAdded'
        QtMocHelpers::SignalData<void(const KScreen::OutputPtr &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'outputRemoved'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'prioritiesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'screen'
        QtMocHelpers::PropertyData<ScreenPtr>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'outputs'
        QtMocHelpers::PropertyData<OutputList>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ValidityFlag'
        QtMocHelpers::EnumData<enum ValidityFlag>(12, 12, QMC::EnumIsScoped).add({
            {   13, ValidityFlag::None },
            {   14, ValidityFlag::RequireAtLeastOneEnabledScreen },
        }),
        // enum 'Feature'
        QtMocHelpers::EnumData<enum Feature>(15, 15, QMC::EnumIsScoped).add({
            {   13, Feature::None },
            {   16, Feature::PrimaryDisplay },
            {   17, Feature::Writable },
            {   18, Feature::PerOutputScaling },
            {   19, Feature::OutputReplication },
            {   20, Feature::AutoRotation },
            {   21, Feature::TabletMode },
            {   22, Feature::SynchronousOutputChanges },
            {   23, Feature::XwaylandScales },
        }),
    };
    return QtMocHelpers::metaObjectData<Config, qt_meta_tag_ZN7KScreen6ConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreen::Config::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen6ConfigE_t>.metaTypes,
    nullptr
} };

void KScreen::Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->outputAdded((*reinterpret_cast<std::add_pointer_t<KScreen::OutputPtr>>(_a[1]))); break;
        case 1: _t->outputRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->prioritiesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)(const KScreen::OutputPtr & )>(_a, &Config::outputAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)(int )>(_a, &Config::outputRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::prioritiesChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ScreenPtr*>(_v) = _t->screen(); break;
        case 1: *reinterpret_cast<OutputList*>(_v) = _t->outputs(); break;
        default: break;
        }
    }
}

const QMetaObject *KScreen::Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KScreen::Config::outputAdded(const KScreen::OutputPtr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KScreen::Config::outputRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KScreen::Config::prioritiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
