// This file was generated by qtwaylandscanner
// source file is kde-output-device-v2.xml

#include "qwayland-kde-output-device-v2.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    kde_output_device_registry_v2::kde_output_device_registry_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_output_device_registry_v2::kde_output_device_registry_v2(struct ::kde_output_device_registry_v2 *obj)
        : m_kde_output_device_registry_v2(obj)
    {
        init_listener();
    }

    kde_output_device_registry_v2::kde_output_device_registry_v2()
        : m_kde_output_device_registry_v2(nullptr)
    {
    }

    kde_output_device_registry_v2::~kde_output_device_registry_v2()
    {
    }

    void kde_output_device_registry_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_output_device_registry_v2 = static_cast<struct ::kde_output_device_registry_v2 *>(wlRegistryBind(registry, id, &kde_output_device_registry_v2_interface, version));
        init_listener();
    }

    void kde_output_device_registry_v2::init(struct ::kde_output_device_registry_v2 *obj)
    {
        m_kde_output_device_registry_v2 = obj;
        init_listener();
    }

    kde_output_device_registry_v2 *kde_output_device_registry_v2::fromObject(struct ::kde_output_device_registry_v2 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_kde_output_device_registry_v2_listener)
            return nullptr;
        return static_cast<kde_output_device_registry_v2 *>(kde_output_device_registry_v2_get_user_data(object));
    }

    bool kde_output_device_registry_v2::isInitialized() const
    {
        return m_kde_output_device_registry_v2 != nullptr;
    }

    uint32_t kde_output_device_registry_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_output_device_registry_v2));
    }

    const struct wl_interface *kde_output_device_registry_v2::interface()
    {
        return &::kde_output_device_registry_v2_interface;
    }

    void kde_output_device_registry_v2::stop()
    {
        ::kde_output_device_registry_v2_stop(
            m_kde_output_device_registry_v2);
    }

    void kde_output_device_registry_v2::kde_output_device_registry_v2_finished()
    {
    }

    void kde_output_device_registry_v2::handle_finished(
        void *data,
        struct ::kde_output_device_registry_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_registry_v2 *>(data)->kde_output_device_registry_v2_finished();
    }

    void kde_output_device_registry_v2::kde_output_device_registry_v2_output(struct ::kde_output_device_v2 *)
    {
    }

    void kde_output_device_registry_v2::handle_output(
        void *data,
        struct ::kde_output_device_registry_v2 *object,
        struct ::kde_output_device_v2 *output)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_registry_v2 *>(data)->kde_output_device_registry_v2_output(
            output);
    }

    const struct kde_output_device_registry_v2_listener kde_output_device_registry_v2::m_kde_output_device_registry_v2_listener = {
        kde_output_device_registry_v2::handle_finished,
        kde_output_device_registry_v2::handle_output,
    };

    void kde_output_device_registry_v2::init_listener()
    {
        kde_output_device_registry_v2_add_listener(m_kde_output_device_registry_v2, &m_kde_output_device_registry_v2_listener, this);
    }

    kde_output_device_v2::kde_output_device_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_output_device_v2::kde_output_device_v2(struct ::kde_output_device_v2 *obj)
        : m_kde_output_device_v2(obj)
    {
        init_listener();
    }

    kde_output_device_v2::kde_output_device_v2()
        : m_kde_output_device_v2(nullptr)
    {
    }

    kde_output_device_v2::~kde_output_device_v2()
    {
    }

    void kde_output_device_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_output_device_v2 = static_cast<struct ::kde_output_device_v2 *>(wlRegistryBind(registry, id, &kde_output_device_v2_interface, version));
        init_listener();
    }

    void kde_output_device_v2::init(struct ::kde_output_device_v2 *obj)
    {
        m_kde_output_device_v2 = obj;
        init_listener();
    }

    kde_output_device_v2 *kde_output_device_v2::fromObject(struct ::kde_output_device_v2 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_kde_output_device_v2_listener)
            return nullptr;
        return static_cast<kde_output_device_v2 *>(kde_output_device_v2_get_user_data(object));
    }

    bool kde_output_device_v2::isInitialized() const
    {
        return m_kde_output_device_v2 != nullptr;
    }

    uint32_t kde_output_device_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_output_device_v2));
    }

    const struct wl_interface *kde_output_device_v2::interface()
    {
        return &::kde_output_device_v2_interface;
    }

    void kde_output_device_v2::release()
    {
        ::kde_output_device_v2_release(
            m_kde_output_device_v2);
        m_kde_output_device_v2 = nullptr;
    }

    void kde_output_device_v2::kde_output_device_v2_geometry(int32_t , int32_t , int32_t , int32_t , int32_t , const QString &, const QString &, int32_t )
    {
    }

    void kde_output_device_v2::handle_geometry(
        void *data,
        struct ::kde_output_device_v2 *object,
        int32_t x,
        int32_t y,
        int32_t physical_width,
        int32_t physical_height,
        int32_t subpixel,
        const char *make,
        const char *model,
        int32_t transform)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_geometry(
            x,
            y,
            physical_width,
            physical_height,
            subpixel,
            QString::fromUtf8(make),
            QString::fromUtf8(model),
            transform);
    }

    void kde_output_device_v2::kde_output_device_v2_current_mode(struct ::kde_output_device_mode_v2 *)
    {
    }

    void kde_output_device_v2::handle_current_mode(
        void *data,
        struct ::kde_output_device_v2 *object,
        struct ::kde_output_device_mode_v2 *mode)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_current_mode(
            mode);
    }

    void kde_output_device_v2::kde_output_device_v2_mode(struct ::kde_output_device_mode_v2 *)
    {
    }

    void kde_output_device_v2::handle_mode(
        void *data,
        struct ::kde_output_device_v2 *object,
        struct ::kde_output_device_mode_v2 *mode)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_mode(
            mode);
    }

    void kde_output_device_v2::kde_output_device_v2_done()
    {
    }

    void kde_output_device_v2::handle_done(
        void *data,
        struct ::kde_output_device_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_done();
    }

    void kde_output_device_v2::kde_output_device_v2_scale(wl_fixed_t )
    {
    }

    void kde_output_device_v2::handle_scale(
        void *data,
        struct ::kde_output_device_v2 *object,
        wl_fixed_t factor)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_scale(
            factor);
    }

    void kde_output_device_v2::kde_output_device_v2_edid(const QString &)
    {
    }

    void kde_output_device_v2::handle_edid(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *raw)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_edid(
            QString::fromUtf8(raw));
    }

    void kde_output_device_v2::kde_output_device_v2_enabled(int32_t )
    {
    }

    void kde_output_device_v2::handle_enabled(
        void *data,
        struct ::kde_output_device_v2 *object,
        int32_t enabled)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_enabled(
            enabled);
    }

    void kde_output_device_v2::kde_output_device_v2_uuid(const QString &)
    {
    }

    void kde_output_device_v2::handle_uuid(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *uuid)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_uuid(
            QString::fromUtf8(uuid));
    }

    void kde_output_device_v2::kde_output_device_v2_serial_number(const QString &)
    {
    }

    void kde_output_device_v2::handle_serial_number(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *serialNumber)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_serial_number(
            QString::fromUtf8(serialNumber));
    }

    void kde_output_device_v2::kde_output_device_v2_eisa_id(const QString &)
    {
    }

    void kde_output_device_v2::handle_eisa_id(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *eisaId)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_eisa_id(
            QString::fromUtf8(eisaId));
    }

    void kde_output_device_v2::kde_output_device_v2_capabilities(uint32_t )
    {
    }

    void kde_output_device_v2::handle_capabilities(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t flags)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_capabilities(
            flags);
    }

    void kde_output_device_v2::kde_output_device_v2_overscan(uint32_t )
    {
    }

    void kde_output_device_v2::handle_overscan(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t overscan)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_overscan(
            overscan);
    }

    void kde_output_device_v2::kde_output_device_v2_vrr_policy(uint32_t )
    {
    }

    void kde_output_device_v2::handle_vrr_policy(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t vrr_policy)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_vrr_policy(
            vrr_policy);
    }

    void kde_output_device_v2::kde_output_device_v2_rgb_range(uint32_t )
    {
    }

    void kde_output_device_v2::handle_rgb_range(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t rgb_range)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_rgb_range(
            rgb_range);
    }

    void kde_output_device_v2::kde_output_device_v2_name(const QString &)
    {
    }

    void kde_output_device_v2::handle_name(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *name)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_name(
            QString::fromUtf8(name));
    }

    void kde_output_device_v2::kde_output_device_v2_high_dynamic_range(uint32_t )
    {
    }

    void kde_output_device_v2::handle_high_dynamic_range(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t hdr_enabled)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_high_dynamic_range(
            hdr_enabled);
    }

    void kde_output_device_v2::kde_output_device_v2_sdr_brightness(uint32_t )
    {
    }

    void kde_output_device_v2::handle_sdr_brightness(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t sdr_brightness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_sdr_brightness(
            sdr_brightness);
    }

    void kde_output_device_v2::kde_output_device_v2_wide_color_gamut(uint32_t )
    {
    }

    void kde_output_device_v2::handle_wide_color_gamut(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t wcg_enabled)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_wide_color_gamut(
            wcg_enabled);
    }

    void kde_output_device_v2::kde_output_device_v2_auto_rotate_policy(uint32_t )
    {
    }

    void kde_output_device_v2::handle_auto_rotate_policy(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t policy)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_auto_rotate_policy(
            policy);
    }

    void kde_output_device_v2::kde_output_device_v2_icc_profile_path(const QString &)
    {
    }

    void kde_output_device_v2::handle_icc_profile_path(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *profile_path)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_icc_profile_path(
            QString::fromUtf8(profile_path));
    }

    void kde_output_device_v2::kde_output_device_v2_brightness_metadata(uint32_t , uint32_t , uint32_t )
    {
    }

    void kde_output_device_v2::handle_brightness_metadata(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t max_peak_brightness,
        uint32_t max_frame_average_brightness,
        uint32_t min_brightness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_brightness_metadata(
            max_peak_brightness,
            max_frame_average_brightness,
            min_brightness);
    }

    void kde_output_device_v2::kde_output_device_v2_brightness_overrides(int32_t , int32_t , int32_t )
    {
    }

    void kde_output_device_v2::handle_brightness_overrides(
        void *data,
        struct ::kde_output_device_v2 *object,
        int32_t max_peak_brightness,
        int32_t max_average_brightness,
        int32_t min_brightness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_brightness_overrides(
            max_peak_brightness,
            max_average_brightness,
            min_brightness);
    }

    void kde_output_device_v2::kde_output_device_v2_sdr_gamut_wideness(uint32_t )
    {
    }

    void kde_output_device_v2::handle_sdr_gamut_wideness(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t gamut_wideness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_sdr_gamut_wideness(
            gamut_wideness);
    }

    void kde_output_device_v2::kde_output_device_v2_color_profile_source(uint32_t )
    {
    }

    void kde_output_device_v2::handle_color_profile_source(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t source)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_color_profile_source(
            source);
    }

    void kde_output_device_v2::kde_output_device_v2_brightness(uint32_t )
    {
    }

    void kde_output_device_v2::handle_brightness(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t brightness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_brightness(
            brightness);
    }

    void kde_output_device_v2::kde_output_device_v2_color_power_tradeoff(uint32_t )
    {
    }

    void kde_output_device_v2::handle_color_power_tradeoff(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t preference)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_color_power_tradeoff(
            preference);
    }

    void kde_output_device_v2::kde_output_device_v2_dimming(uint32_t )
    {
    }

    void kde_output_device_v2::handle_dimming(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t multiplier)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_dimming(
            multiplier);
    }

    void kde_output_device_v2::kde_output_device_v2_replication_source(const QString &)
    {
    }

    void kde_output_device_v2::handle_replication_source(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *source)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_replication_source(
            QString::fromUtf8(source));
    }

    void kde_output_device_v2::kde_output_device_v2_ddc_ci_allowed(uint32_t )
    {
    }

    void kde_output_device_v2::handle_ddc_ci_allowed(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t allowed)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_ddc_ci_allowed(
            allowed);
    }

    void kde_output_device_v2::kde_output_device_v2_max_bits_per_color(uint32_t )
    {
    }

    void kde_output_device_v2::handle_max_bits_per_color(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t max_bpc)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_max_bits_per_color(
            max_bpc);
    }

    void kde_output_device_v2::kde_output_device_v2_max_bits_per_color_range(uint32_t , uint32_t )
    {
    }

    void kde_output_device_v2::handle_max_bits_per_color_range(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t min_value,
        uint32_t max_value)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_max_bits_per_color_range(
            min_value,
            max_value);
    }

    void kde_output_device_v2::kde_output_device_v2_automatic_max_bits_per_color_limit(uint32_t )
    {
    }

    void kde_output_device_v2::handle_automatic_max_bits_per_color_limit(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t max_bpc_limit)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_automatic_max_bits_per_color_limit(
            max_bpc_limit);
    }

    void kde_output_device_v2::kde_output_device_v2_edr_policy(uint32_t )
    {
    }

    void kde_output_device_v2::handle_edr_policy(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t policy)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_edr_policy(
            policy);
    }

    void kde_output_device_v2::kde_output_device_v2_sharpness(uint32_t )
    {
    }

    void kde_output_device_v2::handle_sharpness(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t sharpness)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_sharpness(
            sharpness);
    }

    void kde_output_device_v2::kde_output_device_v2_priority(uint32_t )
    {
    }

    void kde_output_device_v2::handle_priority(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t priority)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_priority(
            priority);
    }

    void kde_output_device_v2::kde_output_device_v2_auto_brightness(uint32_t )
    {
    }

    void kde_output_device_v2::handle_auto_brightness(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t enabled)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_auto_brightness(
            enabled);
    }

    void kde_output_device_v2::kde_output_device_v2_removed()
    {
    }

    void kde_output_device_v2::handle_removed(
        void *data,
        struct ::kde_output_device_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_removed();
    }

    void kde_output_device_v2::kde_output_device_v2_hdr_icc_profile_path(const QString &)
    {
    }

    void kde_output_device_v2::handle_hdr_icc_profile_path(
        void *data,
        struct ::kde_output_device_v2 *object,
        const char *profile_path)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_hdr_icc_profile_path(
            QString::fromUtf8(profile_path));
    }

    void kde_output_device_v2::kde_output_device_v2_hdr_color_profile_source(uint32_t )
    {
    }

    void kde_output_device_v2::handle_hdr_color_profile_source(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t source)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_hdr_color_profile_source(
            source);
    }

    void kde_output_device_v2::kde_output_device_v2_abm_level(uint32_t )
    {
    }

    void kde_output_device_v2::handle_abm_level(
        void *data,
        struct ::kde_output_device_v2 *object,
        uint32_t level)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_v2 *>(data)->kde_output_device_v2_abm_level(
            level);
    }

    const struct kde_output_device_v2_listener kde_output_device_v2::m_kde_output_device_v2_listener = {
        kde_output_device_v2::handle_geometry,
        kde_output_device_v2::handle_current_mode,
        kde_output_device_v2::handle_mode,
        kde_output_device_v2::handle_done,
        kde_output_device_v2::handle_scale,
        kde_output_device_v2::handle_edid,
        kde_output_device_v2::handle_enabled,
        kde_output_device_v2::handle_uuid,
        kde_output_device_v2::handle_serial_number,
        kde_output_device_v2::handle_eisa_id,
        kde_output_device_v2::handle_capabilities,
        kde_output_device_v2::handle_overscan,
        kde_output_device_v2::handle_vrr_policy,
        kde_output_device_v2::handle_rgb_range,
        kde_output_device_v2::handle_name,
        kde_output_device_v2::handle_high_dynamic_range,
        kde_output_device_v2::handle_sdr_brightness,
        kde_output_device_v2::handle_wide_color_gamut,
        kde_output_device_v2::handle_auto_rotate_policy,
        kde_output_device_v2::handle_icc_profile_path,
        kde_output_device_v2::handle_brightness_metadata,
        kde_output_device_v2::handle_brightness_overrides,
        kde_output_device_v2::handle_sdr_gamut_wideness,
        kde_output_device_v2::handle_color_profile_source,
        kde_output_device_v2::handle_brightness,
        kde_output_device_v2::handle_color_power_tradeoff,
        kde_output_device_v2::handle_dimming,
        kde_output_device_v2::handle_replication_source,
        kde_output_device_v2::handle_ddc_ci_allowed,
        kde_output_device_v2::handle_max_bits_per_color,
        kde_output_device_v2::handle_max_bits_per_color_range,
        kde_output_device_v2::handle_automatic_max_bits_per_color_limit,
        kde_output_device_v2::handle_edr_policy,
        kde_output_device_v2::handle_sharpness,
        kde_output_device_v2::handle_priority,
        kde_output_device_v2::handle_auto_brightness,
        kde_output_device_v2::handle_removed,
        kde_output_device_v2::handle_hdr_icc_profile_path,
        kde_output_device_v2::handle_hdr_color_profile_source,
        kde_output_device_v2::handle_abm_level,
    };

    void kde_output_device_v2::init_listener()
    {
        kde_output_device_v2_add_listener(m_kde_output_device_v2, &m_kde_output_device_v2_listener, this);
    }

    kde_output_device_mode_v2::kde_output_device_mode_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_output_device_mode_v2::kde_output_device_mode_v2(struct ::kde_output_device_mode_v2 *obj)
        : m_kde_output_device_mode_v2(obj)
    {
        init_listener();
    }

    kde_output_device_mode_v2::kde_output_device_mode_v2()
        : m_kde_output_device_mode_v2(nullptr)
    {
    }

    kde_output_device_mode_v2::~kde_output_device_mode_v2()
    {
    }

    void kde_output_device_mode_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_output_device_mode_v2 = static_cast<struct ::kde_output_device_mode_v2 *>(wlRegistryBind(registry, id, &kde_output_device_mode_v2_interface, version));
        init_listener();
    }

    void kde_output_device_mode_v2::init(struct ::kde_output_device_mode_v2 *obj)
    {
        m_kde_output_device_mode_v2 = obj;
        init_listener();
    }

    kde_output_device_mode_v2 *kde_output_device_mode_v2::fromObject(struct ::kde_output_device_mode_v2 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_kde_output_device_mode_v2_listener)
            return nullptr;
        return static_cast<kde_output_device_mode_v2 *>(kde_output_device_mode_v2_get_user_data(object));
    }

    bool kde_output_device_mode_v2::isInitialized() const
    {
        return m_kde_output_device_mode_v2 != nullptr;
    }

    uint32_t kde_output_device_mode_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_output_device_mode_v2));
    }

    const struct wl_interface *kde_output_device_mode_v2::interface()
    {
        return &::kde_output_device_mode_v2_interface;
    }

    void kde_output_device_mode_v2::kde_output_device_mode_v2_size(int32_t , int32_t )
    {
    }

    void kde_output_device_mode_v2::handle_size(
        void *data,
        struct ::kde_output_device_mode_v2 *object,
        int32_t width,
        int32_t height)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_mode_v2 *>(data)->kde_output_device_mode_v2_size(
            width,
            height);
    }

    void kde_output_device_mode_v2::kde_output_device_mode_v2_refresh(int32_t )
    {
    }

    void kde_output_device_mode_v2::handle_refresh(
        void *data,
        struct ::kde_output_device_mode_v2 *object,
        int32_t refresh)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_mode_v2 *>(data)->kde_output_device_mode_v2_refresh(
            refresh);
    }

    void kde_output_device_mode_v2::kde_output_device_mode_v2_preferred()
    {
    }

    void kde_output_device_mode_v2::handle_preferred(
        void *data,
        struct ::kde_output_device_mode_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_mode_v2 *>(data)->kde_output_device_mode_v2_preferred();
    }

    void kde_output_device_mode_v2::kde_output_device_mode_v2_removed()
    {
    }

    void kde_output_device_mode_v2::handle_removed(
        void *data,
        struct ::kde_output_device_mode_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_mode_v2 *>(data)->kde_output_device_mode_v2_removed();
    }

    void kde_output_device_mode_v2::kde_output_device_mode_v2_flags(uint32_t )
    {
    }

    void kde_output_device_mode_v2::handle_flags(
        void *data,
        struct ::kde_output_device_mode_v2 *object,
        uint32_t flags)
    {
        Q_UNUSED(object);
        static_cast<kde_output_device_mode_v2 *>(data)->kde_output_device_mode_v2_flags(
            flags);
    }

    const struct kde_output_device_mode_v2_listener kde_output_device_mode_v2::m_kde_output_device_mode_v2_listener = {
        kde_output_device_mode_v2::handle_size,
        kde_output_device_mode_v2::handle_refresh,
        kde_output_device_mode_v2::handle_preferred,
        kde_output_device_mode_v2::handle_removed,
        kde_output_device_mode_v2::handle_flags,
    };

    void kde_output_device_mode_v2::init_listener()
    {
        kde_output_device_mode_v2_add_listener(m_kde_output_device_mode_v2, &m_kde_output_device_mode_v2_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
