/****************************************************************************
** Meta object code from reading C++ file 'xcbeventlistener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libkscreen-6.7.4/backends/xcbeventlistener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xcbeventlistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16XCBEventListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto XCBEventListener::qt_create_metaobjectdata<qt_meta_tag_ZN16XCBEventListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XCBEventListener",
        "screenChanged",
        "",
        "xcb_randr_rotation_t",
        "rotation",
        "QSize",
        "sizePx",
        "sizeMm",
        "outputsChanged",
        "crtcChanged",
        "xcb_randr_crtc_t",
        "crtc",
        "xcb_randr_mode_t",
        "mode",
        "QRect",
        "geom",
        "xcb_timestamp_t",
        "timestamp",
        "outputChanged",
        "xcb_randr_output_t",
        "output",
        "xcb_randr_connection_t",
        "connection",
        "outputPropertyChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void(xcb_randr_rotation_t, const QSize &, const QSize &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'outputsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'crtcChanged'
        QtMocHelpers::SignalData<void(xcb_randr_crtc_t, xcb_randr_mode_t, xcb_randr_rotation_t, const QRect &, xcb_timestamp_t)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 14, 15 },
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void(xcb_randr_output_t, xcb_randr_crtc_t, xcb_randr_mode_t, xcb_randr_connection_t)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 21, 22 },
        }}),
        // Signal 'outputPropertyChanged'
        QtMocHelpers::SignalData<void(xcb_randr_output_t)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XCBEventListener, qt_meta_tag_ZN16XCBEventListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XCBEventListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16XCBEventListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16XCBEventListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16XCBEventListenerE_t>.metaTypes,
    nullptr
} };

void XCBEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XCBEventListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->screenChanged((*reinterpret_cast<std::add_pointer_t<xcb_randr_rotation_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3]))); break;
        case 1: _t->outputsChanged(); break;
        case 2: _t->crtcChanged((*reinterpret_cast<std::add_pointer_t<xcb_randr_crtc_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<xcb_randr_mode_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<xcb_randr_rotation_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<xcb_timestamp_t>>(_a[5]))); break;
        case 3: _t->outputChanged((*reinterpret_cast<std::add_pointer_t<xcb_randr_output_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<xcb_randr_crtc_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<xcb_randr_mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<xcb_randr_connection_t>>(_a[4]))); break;
        case 4: _t->outputPropertyChanged((*reinterpret_cast<std::add_pointer_t<xcb_randr_output_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XCBEventListener::*)(xcb_randr_rotation_t , const QSize & , const QSize & )>(_a, &XCBEventListener::screenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XCBEventListener::*)()>(_a, &XCBEventListener::outputsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XCBEventListener::*)(xcb_randr_crtc_t , xcb_randr_mode_t , xcb_randr_rotation_t , const QRect & , xcb_timestamp_t )>(_a, &XCBEventListener::crtcChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XCBEventListener::*)(xcb_randr_output_t , xcb_randr_crtc_t , xcb_randr_mode_t , xcb_randr_connection_t )>(_a, &XCBEventListener::outputChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (XCBEventListener::*)(xcb_randr_output_t )>(_a, &XCBEventListener::outputPropertyChanged, 4))
            return;
    }
}

const QMetaObject *XCBEventListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XCBEventListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16XCBEventListenerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QAbstractNativeEventFilter"))
        return static_cast< QAbstractNativeEventFilter*>(this);
    return QObject::qt_metacast(_clname);
}

int XCBEventListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void XCBEventListener::screenChanged(xcb_randr_rotation_t _t1, const QSize & _t2, const QSize & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void XCBEventListener::outputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XCBEventListener::crtcChanged(xcb_randr_crtc_t _t1, xcb_randr_mode_t _t2, xcb_randr_rotation_t _t3, const QRect & _t4, xcb_timestamp_t _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 3
void XCBEventListener::outputChanged(xcb_randr_output_t _t1, xcb_randr_crtc_t _t2, xcb_randr_mode_t _t3, xcb_randr_connection_t _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void XCBEventListener::outputPropertyChanged(xcb_randr_output_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
