/****************************************************************************
** Meta object code from reading C++ file 'dpms.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libkscreen-6.7.4/src/libdpms/dpms.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dpms.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KScreen4DpmsE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::Dpms::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen4DpmsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::Dpms",
        "supportedChanged",
        "",
        "supported",
        "modeChanged",
        "Mode",
        "mode",
        "QScreen*",
        "screen",
        "hasPendingChangesChanged",
        "hasPendingChanges",
        "switchMode",
        "QList<QScreen*>",
        "isSupported",
        "On",
        "Standby",
        "Suspend",
        "Off",
        "Toggle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'supportedChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(enum Mode, QScreen *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'hasPendingChangesChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Method 'switchMode'
        QtMocHelpers::MethodData<void(enum Mode, const QList<QScreen*> &)>(11, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 12, 8 },
        }}),
        // Method 'switchMode'
        QtMocHelpers::MethodData<void(enum Mode)>(11, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isSupported'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'hasPendingChanges'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(5, 5, QMC::EnumFlags{}).add({
            {   14, Mode::On },
            {   15, Mode::Standby },
            {   16, Mode::Suspend },
            {   17, Mode::Off },
            {   18, Mode::Toggle },
        }),
    };
    return QtMocHelpers::metaObjectData<Dpms, qt_meta_tag_ZN7KScreen4DpmsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreen::Dpms::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4DpmsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4DpmsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen4DpmsE_t>.metaTypes,
    nullptr
} };

void KScreen::Dpms::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Dpms *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->supportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<enum Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[2]))); break;
        case 2: _t->hasPendingChangesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->switchMode((*reinterpret_cast<std::add_pointer_t<enum Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QScreen*>>>(_a[2]))); break;
        case 4: _t->switchMode((*reinterpret_cast<std::add_pointer_t<enum Mode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QScreen*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Dpms::*)(bool )>(_a, &Dpms::supportedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dpms::*)(Mode , QScreen * )>(_a, &Dpms::modeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dpms::*)(bool )>(_a, &Dpms::hasPendingChangesChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isSupported(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasPendingChanges(); break;
        default: break;
        }
    }
}

const QMetaObject *KScreen::Dpms::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Dpms::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen4DpmsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Dpms::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KScreen::Dpms::supportedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KScreen::Dpms::modeChanged(Mode _t1, QScreen * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KScreen::Dpms::hasPendingChangesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
