/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KScreen.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef BACKENDLOADERADAPTOR_H
#define BACKENDLOADERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "backendloader.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KScreen
 */
class BackendLoaderAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KScreen")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KScreen\">\n"
"    <method name=\"backend\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"requestBackend\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"    </method>\n"
"    <method name=\"quit\"/>\n"
"  </interface>\n"
        "")
public:
    BackendLoaderAdaptor(BackendLoader *parent);
    ~BackendLoaderAdaptor() override;

    inline BackendLoader *parent() const
    { return static_cast<BackendLoader *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString backend();
    void quit();
    bool requestBackend(const QString &in0, const QVariantMap &in1);
Q_SIGNALS: // SIGNALS
};

#endif
