// This file was generated by qtwaylandscanner
// source file is dpms.xml

#ifndef QT_WAYLAND_DPMS
#define QT_WAYLAND_DPMS

#include "wayland-dpms-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_kwin_dpms_manager
    {
    public:
        org_kde_kwin_dpms_manager(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_dpms_manager(struct ::org_kde_kwin_dpms_manager *object);
        org_kde_kwin_dpms_manager();

        virtual ~org_kde_kwin_dpms_manager();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_dpms_manager *object);

        struct ::org_kde_kwin_dpms_manager *object() { return m_org_kde_kwin_dpms_manager; }
        const struct ::org_kde_kwin_dpms_manager *object() const { return m_org_kde_kwin_dpms_manager; }
        static org_kde_kwin_dpms_manager *fromObject(struct ::org_kde_kwin_dpms_manager *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_kwin_dpms *get(struct ::wl_output *output);

    private:
        struct ::org_kde_kwin_dpms_manager *m_org_kde_kwin_dpms_manager;
    };

    class  org_kde_kwin_dpms
    {
    public:
        org_kde_kwin_dpms(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_dpms(struct ::org_kde_kwin_dpms *object);
        org_kde_kwin_dpms();

        virtual ~org_kde_kwin_dpms();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_dpms *object);

        struct ::org_kde_kwin_dpms *object() { return m_org_kde_kwin_dpms; }
        const struct ::org_kde_kwin_dpms *object() const { return m_org_kde_kwin_dpms; }
        static org_kde_kwin_dpms *fromObject(struct ::org_kde_kwin_dpms *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum mode {
            mode_On = 0,
            mode_Standby = 1,
            mode_Suspend = 2,
            mode_Off = 3,
        };

        void set(uint32_t mode);
        void release();

    protected:
        virtual void org_kde_kwin_dpms_supported(uint32_t supported);
        virtual void org_kde_kwin_dpms_mode(uint32_t mode);
        virtual void org_kde_kwin_dpms_done();

    private:
        void init_listener();
        static const struct org_kde_kwin_dpms_listener m_org_kde_kwin_dpms_listener;
        static void handle_supported(
            void *data,
            struct ::org_kde_kwin_dpms *object,
            uint32_t supported);
        static void handle_mode(
            void *data,
            struct ::org_kde_kwin_dpms *object,
            uint32_t mode);
        static void handle_done(
            void *data,
            struct ::org_kde_kwin_dpms *object);
        struct ::org_kde_kwin_dpms *m_org_kde_kwin_dpms;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
