/****************************************************************************
** Meta object code from reading C++ file 'output.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkscreen-6.7.4/src/output.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'output.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KScreen8ModeInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::ModeInfo::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen8ModeInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::ModeInfo",
        "Flag",
        "Custom",
        "ReducedBlanking"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Flag'
        QtMocHelpers::EnumData<enum Flag>(1, 1, QMC::EnumIsScoped).add({
            {    2, Flag::Custom },
            {    3, Flag::ReducedBlanking },
        }),
    };
    return QtMocHelpers::metaObjectData<ModeInfo, qt_meta_tag_ZN7KScreen8ModeInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreen::ModeInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen8ModeInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen8ModeInfoE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen8ModeInfoE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN7KScreen6OutputE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::Output::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen6OutputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::Output",
        "RegisterEnumClassesUnscoped",
        "false",
        "outputChanged",
        "",
        "posChanged",
        "sizeChanged",
        "currentModeIdChanged",
        "rotationChanged",
        "isConnectedChanged",
        "isEnabledChanged",
        "priorityChanged",
        "clonesChanged",
        "replicationSourceChanged",
        "scaleChanged",
        "explicitLogicalSizeChanged",
        "followPreferredModeChanged",
        "followPreferredMode",
        "capabilitiesChanged",
        "overscanChanged",
        "vrrPolicyChanged",
        "rgbRangeChanged",
        "hdrEnabledChanged",
        "sdrBrightnessChanged",
        "wcgEnabledChanged",
        "autoRotatePolicyChanged",
        "iccProfilePathChanged",
        "sdrGamutWidenessChanged",
        "maxPeakBrightnessChanged",
        "maxAverageBrightnessChanged",
        "minBrightnessChanged",
        "maxPeakBrightnessOverrideChanged",
        "maxAverageBrightnessOverrideChanged",
        "minBrightnessOverrideChanged",
        "colorProfileSourceChanged",
        "hdrColorProfileSourceChanged",
        "brightnessChanged",
        "vendorChanged",
        "modelChanged",
        "colorPowerPreferenceChanged",
        "dimmingChanged",
        "uuidChanged",
        "ddcCiAllowedChanged",
        "maxBitsPerColorChanged",
        "edrPolicyChanged",
        "sharpnessChanged",
        "customModesChanged",
        "automaticBrightnessChanged",
        "hdrIccProfilePathChanged",
        "abmLevelChanged",
        "modesChanged",
        "mode",
        "ModePtr",
        "id",
        "currentMode",
        "preferredModeId",
        "preferredMode",
        "isHorizontal",
        "name",
        "vendor",
        "model",
        "type",
        "Type",
        "icon",
        "modes",
        "ModeList",
        "pos",
        "QPoint",
        "size",
        "QSize",
        "rotation",
        "Rotation",
        "currentModeId",
        "connected",
        "enabled",
        "priority",
        "uint32_t",
        "clones",
        "QList<int>",
        "replicationSource",
        "edid",
        "KScreen::Edid*",
        "sizeMm",
        "scale",
        "explicitLogicalSize",
        "QSizeF",
        "capabilities",
        "Capabilities",
        "overscan",
        "vrrPolicy",
        "VrrPolicy",
        "rgbRange",
        "RgbRange",
        "hdrEnabled",
        "sdrBrightness",
        "wcgEnabled",
        "autoRotatePolicy",
        "AutoRotatePolicy",
        "iccProfilePath",
        "colorProfileSource",
        "ColorProfileSource",
        "brightness",
        "colorPowerPreference",
        "ColorPowerTradeoff",
        "dimming",
        "ddcCiAllowed",
        "Unknown",
        "VGA",
        "DVI",
        "DVII",
        "DVIA",
        "DVID",
        "HDMI",
        "Panel",
        "TV",
        "TVComposite",
        "TVSVideo",
        "TVComponent",
        "TVSCART",
        "TVC4",
        "DisplayPort",
        "None",
        "Left",
        "Inverted",
        "Right",
        "Flipped",
        "Flipped90",
        "Flipped180",
        "Flipped270",
        "Capability",
        "Overscan",
        "Vrr",
        "HighDynamicRange",
        "WideColorGamut",
        "AutoRotation",
        "IccProfile",
        "BrightnessControl",
        "BuiltInColorProfile",
        "DdcCi",
        "MaxBitsPerColor",
        "ExtendedDynamicRange",
        "SharpnessControl",
        "CustomModes",
        "AutomaticBrightness",
        "HdrIccProfile",
        "AbmLevel",
        "Never",
        "Always",
        "Automatic",
        "Full",
        "Limited",
        "InTabletMode",
        "sRGB",
        "ICC",
        "EDID",
        "PreferEfficiency",
        "PreferAccuracy",
        "EdrPolicy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'posChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModeIdChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isConnectedChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isEnabledChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'priorityChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clonesChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replicationSourceChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'explicitLogicalSizeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'followPreferredModeChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overscanChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vrrPolicyChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rgbRangeChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrEnabledChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdrBrightnessChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wcgEnabledChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoRotatePolicyChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iccProfilePathChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdrGamutWidenessChanged'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxPeakBrightnessChanged'
        QtMocHelpers::SignalData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxAverageBrightnessChanged'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minBrightnessChanged'
        QtMocHelpers::SignalData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxPeakBrightnessOverrideChanged'
        QtMocHelpers::SignalData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxAverageBrightnessOverrideChanged'
        QtMocHelpers::SignalData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minBrightnessOverrideChanged'
        QtMocHelpers::SignalData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorProfileSourceChanged'
        QtMocHelpers::SignalData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrColorProfileSourceChanged'
        QtMocHelpers::SignalData<void()>(35, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(36, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vendorChanged'
        QtMocHelpers::SignalData<void()>(37, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(38, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorPowerPreferenceChanged'
        QtMocHelpers::SignalData<void()>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dimmingChanged'
        QtMocHelpers::SignalData<void()>(40, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uuidChanged'
        QtMocHelpers::SignalData<void()>(41, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ddcCiAllowedChanged'
        QtMocHelpers::SignalData<void()>(42, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxBitsPerColorChanged'
        QtMocHelpers::SignalData<void()>(43, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edrPolicyChanged'
        QtMocHelpers::SignalData<void()>(44, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sharpnessChanged'
        QtMocHelpers::SignalData<void()>(45, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customModesChanged'
        QtMocHelpers::SignalData<void()>(46, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticBrightnessChanged'
        QtMocHelpers::SignalData<void()>(47, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrIccProfilePathChanged'
        QtMocHelpers::SignalData<void()>(48, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abmLevelChanged'
        QtMocHelpers::SignalData<void()>(49, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modesChanged'
        QtMocHelpers::SignalData<void()>(50, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'mode'
        QtMocHelpers::MethodData<ModePtr(const QString &) const>(51, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 53 },
        }}),
        // Method 'currentMode'
        QtMocHelpers::MethodData<ModePtr() const>(54, 4, QMC::AccessPublic, 0x80000000 | 52),
        // Method 'preferredModeId'
        QtMocHelpers::MethodData<QString() const>(55, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'preferredMode'
        QtMocHelpers::MethodData<ModePtr() const>(56, 4, QMC::AccessPublic, 0x80000000 | 52),
        // Method 'isHorizontal'
        QtMocHelpers::MethodData<bool() const>(57, 4, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'vendor'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'modes'
        QtMocHelpers::PropertyData<ModeList>(64, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 45),
        // property 'pos'
        QtMocHelpers::PropertyData<QPoint>(66, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'size'
        QtMocHelpers::PropertyData<QSize>(68, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'rotation'
        QtMocHelpers::PropertyData<enum Rotation>(70, 0x80000000 | 71, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'currentModeId'
        QtMocHelpers::PropertyData<QString>(72, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'preferredModeId'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'priority'
        QtMocHelpers::PropertyData<uint32_t>(75, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'clones'
        QtMocHelpers::PropertyData<QList<int>>(77, 0x80000000 | 78, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'replicationSource'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'edid'
        QtMocHelpers::PropertyData<KScreen::Edid*>(80, 0x80000000 | 81, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sizeMm'
        QtMocHelpers::PropertyData<QSize>(82, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'scale'
        QtMocHelpers::PropertyData<qreal>(83, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'followPreferredMode'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'explicitLogicalSize'
        QtMocHelpers::PropertyData<QSizeF>(84, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'capabilities'
        QtMocHelpers::PropertyData<Capabilities>(86, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'overscan'
        QtMocHelpers::PropertyData<uint32_t>(88, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'vrrPolicy'
        QtMocHelpers::PropertyData<enum VrrPolicy>(89, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'rgbRange'
        QtMocHelpers::PropertyData<enum RgbRange>(91, 0x80000000 | 92, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'hdrEnabled'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'sdrBrightness'
        QtMocHelpers::PropertyData<uint32_t>(94, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'wcgEnabled'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'autoRotatePolicy'
        QtMocHelpers::PropertyData<enum AutoRotatePolicy>(96, 0x80000000 | 97, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'iccProfilePath'
        QtMocHelpers::PropertyData<QString>(98, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'colorProfileSource'
        QtMocHelpers::PropertyData<enum ColorProfileSource>(99, 0x80000000 | 100, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 29),
        // property 'brightness'
        QtMocHelpers::PropertyData<double>(101, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'colorPowerPreference'
        QtMocHelpers::PropertyData<enum ColorPowerTradeoff>(102, 0x80000000 | 103, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 34),
        // property 'dimming'
        QtMocHelpers::PropertyData<double>(104, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'ddcCiAllowed'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(62, 62, QMC::EnumFlags{}).add({
            {  106, Type::Unknown },
            {  107, Type::VGA },
            {  108, Type::DVI },
            {  109, Type::DVII },
            {  110, Type::DVIA },
            {  111, Type::DVID },
            {  112, Type::HDMI },
            {  113, Type::Panel },
            {  114, Type::TV },
            {  115, Type::TVComposite },
            {  116, Type::TVSVideo },
            {  117, Type::TVComponent },
            {  118, Type::TVSCART },
            {  119, Type::TVC4 },
            {  120, Type::DisplayPort },
        }),
        // enum 'Rotation'
        QtMocHelpers::EnumData<enum Rotation>(71, 71, QMC::EnumFlags{}).add({
            {  121, Rotation::None },
            {  122, Rotation::Left },
            {  123, Rotation::Inverted },
            {  124, Rotation::Right },
            {  125, Rotation::Flipped },
            {  126, Rotation::Flipped90 },
            {  127, Rotation::Flipped180 },
            {  128, Rotation::Flipped270 },
        }),
        // enum 'Capability'
        QtMocHelpers::EnumData<enum Capability>(129, 129, QMC::EnumIsScoped).add({
            {  130, Capability::Overscan },
            {  131, Capability::Vrr },
            {   92, Capability::RgbRange },
            {  132, Capability::HighDynamicRange },
            {  133, Capability::WideColorGamut },
            {  134, Capability::AutoRotation },
            {  135, Capability::IccProfile },
            {  136, Capability::BrightnessControl },
            {  137, Capability::BuiltInColorProfile },
            {  138, Capability::DdcCi },
            {  139, Capability::MaxBitsPerColor },
            {  140, Capability::ExtendedDynamicRange },
            {  141, Capability::SharpnessControl },
            {  142, Capability::CustomModes },
            {  143, Capability::AutomaticBrightness },
            {  144, Capability::HdrIccProfile },
            {  145, Capability::AbmLevel },
        }),
        // flag 'Capabilities'
        QtMocHelpers::EnumData<Capabilities>(87, 129, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {  130, Capability::Overscan },
            {  131, Capability::Vrr },
            {   92, Capability::RgbRange },
            {  132, Capability::HighDynamicRange },
            {  133, Capability::WideColorGamut },
            {  134, Capability::AutoRotation },
            {  135, Capability::IccProfile },
            {  136, Capability::BrightnessControl },
            {  137, Capability::BuiltInColorProfile },
            {  138, Capability::DdcCi },
            {  139, Capability::MaxBitsPerColor },
            {  140, Capability::ExtendedDynamicRange },
            {  141, Capability::SharpnessControl },
            {  142, Capability::CustomModes },
            {  143, Capability::AutomaticBrightness },
            {  144, Capability::HdrIccProfile },
            {  145, Capability::AbmLevel },
        }),
        // enum 'VrrPolicy'
        QtMocHelpers::EnumData<enum VrrPolicy>(90, 90, QMC::EnumIsScoped).add({
            {  146, VrrPolicy::Never },
            {  147, VrrPolicy::Always },
            {  148, VrrPolicy::Automatic },
        }),
        // enum 'RgbRange'
        QtMocHelpers::EnumData<enum RgbRange>(92, 92, QMC::EnumIsScoped).add({
            {  148, RgbRange::Automatic },
            {  149, RgbRange::Full },
            {  150, RgbRange::Limited },
        }),
        // enum 'AutoRotatePolicy'
        QtMocHelpers::EnumData<enum AutoRotatePolicy>(97, 97, QMC::EnumIsScoped).add({
            {  146, AutoRotatePolicy::Never },
            {  151, AutoRotatePolicy::InTabletMode },
            {  147, AutoRotatePolicy::Always },
        }),
        // enum 'ColorProfileSource'
        QtMocHelpers::EnumData<enum ColorProfileSource>(100, 100, QMC::EnumIsScoped).add({
            {  152, ColorProfileSource::sRGB },
            {  153, ColorProfileSource::ICC },
            {  154, ColorProfileSource::EDID },
        }),
        // enum 'ColorPowerTradeoff'
        QtMocHelpers::EnumData<enum ColorPowerTradeoff>(103, 103, QMC::EnumIsScoped).add({
            {  155, ColorPowerTradeoff::PreferEfficiency },
            {  156, ColorPowerTradeoff::PreferAccuracy },
        }),
        // enum 'EdrPolicy'
        QtMocHelpers::EnumData<enum EdrPolicy>(157, 157, QMC::EnumIsScoped).add({
            {  146, EdrPolicy::Never },
            {  147, EdrPolicy::Always },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Output, qt_meta_tag_ZN7KScreen6OutputE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KScreen::Output::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6OutputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6OutputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen6OutputE_t>.metaTypes,
    nullptr
} };

void KScreen::Output::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Output *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->outputChanged(); break;
        case 1: _t->posChanged(); break;
        case 2: _t->sizeChanged(); break;
        case 3: _t->currentModeIdChanged(); break;
        case 4: _t->rotationChanged(); break;
        case 5: _t->isConnectedChanged(); break;
        case 6: _t->isEnabledChanged(); break;
        case 7: _t->priorityChanged(); break;
        case 8: _t->clonesChanged(); break;
        case 9: _t->replicationSourceChanged(); break;
        case 10: _t->scaleChanged(); break;
        case 11: _t->explicitLogicalSizeChanged(); break;
        case 12: _t->followPreferredModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->capabilitiesChanged(); break;
        case 14: _t->overscanChanged(); break;
        case 15: _t->vrrPolicyChanged(); break;
        case 16: _t->rgbRangeChanged(); break;
        case 17: _t->hdrEnabledChanged(); break;
        case 18: _t->sdrBrightnessChanged(); break;
        case 19: _t->wcgEnabledChanged(); break;
        case 20: _t->autoRotatePolicyChanged(); break;
        case 21: _t->iccProfilePathChanged(); break;
        case 22: _t->sdrGamutWidenessChanged(); break;
        case 23: _t->maxPeakBrightnessChanged(); break;
        case 24: _t->maxAverageBrightnessChanged(); break;
        case 25: _t->minBrightnessChanged(); break;
        case 26: _t->maxPeakBrightnessOverrideChanged(); break;
        case 27: _t->maxAverageBrightnessOverrideChanged(); break;
        case 28: _t->minBrightnessOverrideChanged(); break;
        case 29: _t->colorProfileSourceChanged(); break;
        case 30: _t->hdrColorProfileSourceChanged(); break;
        case 31: _t->brightnessChanged(); break;
        case 32: _t->vendorChanged(); break;
        case 33: _t->modelChanged(); break;
        case 34: _t->colorPowerPreferenceChanged(); break;
        case 35: _t->dimmingChanged(); break;
        case 36: _t->uuidChanged(); break;
        case 37: _t->ddcCiAllowedChanged(); break;
        case 38: _t->maxBitsPerColorChanged(); break;
        case 39: _t->edrPolicyChanged(); break;
        case 40: _t->sharpnessChanged(); break;
        case 41: _t->customModesChanged(); break;
        case 42: _t->automaticBrightnessChanged(); break;
        case 43: _t->hdrIccProfilePathChanged(); break;
        case 44: _t->abmLevelChanged(); break;
        case 45: _t->modesChanged(); break;
        case 46: { ModePtr _r = _t->mode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 47: { ModePtr _r = _t->currentMode();
            if (_a[0]) *reinterpret_cast<ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 48: { QString _r = _t->preferredModeId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 49: { ModePtr _r = _t->preferredMode();
            if (_a[0]) *reinterpret_cast<ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->isHorizontal();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::outputChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::posChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::sizeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::currentModeIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::rotationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::isConnectedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::isEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::priorityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::clonesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::replicationSourceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::scaleChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::explicitLogicalSizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)(bool )>(_a, &Output::followPreferredModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::capabilitiesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::overscanChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::vrrPolicyChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::rgbRangeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::hdrEnabledChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::sdrBrightnessChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::wcgEnabledChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::autoRotatePolicyChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::iccProfilePathChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::sdrGamutWidenessChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::maxPeakBrightnessChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::maxAverageBrightnessChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::minBrightnessChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::maxPeakBrightnessOverrideChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::maxAverageBrightnessOverrideChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::minBrightnessOverrideChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::colorProfileSourceChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::hdrColorProfileSourceChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::brightnessChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::vendorChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::modelChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::colorPowerPreferenceChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::dimmingChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::uuidChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::ddcCiAllowedChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::maxBitsPerColorChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::edrPolicyChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::sharpnessChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::customModesChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::automaticBrightnessChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::hdrIccProfilePathChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::abmLevelChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (Output::*)()>(_a, &Output::modesChanged, 45))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 4: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 6: *reinterpret_cast<ModeList*>(_v) = _t->modes(); break;
        case 7: *reinterpret_cast<QPoint*>(_v) = _t->pos(); break;
        case 8: *reinterpret_cast<QSize*>(_v) = _t->size(); break;
        case 9: *reinterpret_cast<enum Rotation*>(_v) = _t->rotation(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->currentModeId(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->preferredModeId(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isConnected(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 14: *reinterpret_cast<uint32_t*>(_v) = _t->priority(); break;
        case 15: *reinterpret_cast<QList<int>*>(_v) = _t->clones(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->replicationSource(); break;
        case 17: *reinterpret_cast<KScreen::Edid**>(_v) = _t->edid(); break;
        case 18: *reinterpret_cast<QSize*>(_v) = _t->sizeMm(); break;
        case 19: *reinterpret_cast<qreal*>(_v) = _t->scale(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->followPreferredMode(); break;
        case 21: *reinterpret_cast<QSizeF*>(_v) = _t->explicitLogicalSize(); break;
        case 22: QtMocHelpers::assignFlags<Capabilities>(_v, _t->capabilities()); break;
        case 23: *reinterpret_cast<uint32_t*>(_v) = _t->overscan(); break;
        case 24: *reinterpret_cast<enum VrrPolicy*>(_v) = _t->vrrPolicy(); break;
        case 25: *reinterpret_cast<enum RgbRange*>(_v) = _t->rgbRange(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isHdrEnabled(); break;
        case 27: *reinterpret_cast<uint32_t*>(_v) = _t->sdrBrightness(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isWcgEnabled(); break;
        case 29: *reinterpret_cast<enum AutoRotatePolicy*>(_v) = _t->autoRotatePolicy(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->iccProfilePath(); break;
        case 31: *reinterpret_cast<enum ColorProfileSource*>(_v) = _t->colorProfileSource(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->brightness(); break;
        case 33: *reinterpret_cast<enum ColorPowerTradeoff*>(_v) = _t->colorPowerPreference(); break;
        case 34: *reinterpret_cast<double*>(_v) = _t->dimming(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->ddcCiAllowed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setVendor(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setModel(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 5: _t->setIcon(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setPos(*reinterpret_cast<QPoint*>(_v)); break;
        case 8: _t->setSize(*reinterpret_cast<QSize*>(_v)); break;
        case 9: _t->setRotation(*reinterpret_cast<enum Rotation*>(_v)); break;
        case 10: _t->setCurrentModeId(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setConnected(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setPriority(*reinterpret_cast<uint32_t*>(_v)); break;
        case 15: _t->setClones(*reinterpret_cast<QList<int>*>(_v)); break;
        case 16: _t->setReplicationSource(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setScale(*reinterpret_cast<qreal*>(_v)); break;
        case 20: _t->setFollowPreferredMode(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setExplicitLogicalSize(*reinterpret_cast<QSizeF*>(_v)); break;
        case 23: _t->setOverscan(*reinterpret_cast<uint32_t*>(_v)); break;
        case 24: _t->setVrrPolicy(*reinterpret_cast<enum VrrPolicy*>(_v)); break;
        case 25: _t->setRgbRange(*reinterpret_cast<enum RgbRange*>(_v)); break;
        case 26: _t->setHdrEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setSdrBrightness(*reinterpret_cast<uint32_t*>(_v)); break;
        case 28: _t->setWcgEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setAutoRotatePolicy(*reinterpret_cast<enum AutoRotatePolicy*>(_v)); break;
        case 30: _t->setIccProfilePath(*reinterpret_cast<QString*>(_v)); break;
        case 31: _t->setColorProfileSource(*reinterpret_cast<enum ColorProfileSource*>(_v)); break;
        case 32: _t->setBrightness(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setColorPowerPreference(*reinterpret_cast<enum ColorPowerTradeoff*>(_v)); break;
        case 34: _t->setDimming(*reinterpret_cast<double*>(_v)); break;
        case 35: _t->setDdcCiAllowed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KScreen::Output::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Output::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen6OutputE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Output::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 51;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void KScreen::Output::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KScreen::Output::posChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KScreen::Output::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KScreen::Output::currentModeIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KScreen::Output::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KScreen::Output::isConnectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KScreen::Output::isEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KScreen::Output::priorityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KScreen::Output::clonesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KScreen::Output::replicationSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KScreen::Output::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KScreen::Output::explicitLogicalSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KScreen::Output::followPreferredModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KScreen::Output::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KScreen::Output::overscanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KScreen::Output::vrrPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KScreen::Output::rgbRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KScreen::Output::hdrEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KScreen::Output::sdrBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KScreen::Output::wcgEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KScreen::Output::autoRotatePolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KScreen::Output::iccProfilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KScreen::Output::sdrGamutWidenessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KScreen::Output::maxPeakBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void KScreen::Output::maxAverageBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void KScreen::Output::minBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void KScreen::Output::maxPeakBrightnessOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void KScreen::Output::maxAverageBrightnessOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void KScreen::Output::minBrightnessOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void KScreen::Output::colorProfileSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void KScreen::Output::hdrColorProfileSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void KScreen::Output::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void KScreen::Output::vendorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void KScreen::Output::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void KScreen::Output::colorPowerPreferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void KScreen::Output::dimmingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void KScreen::Output::uuidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void KScreen::Output::ddcCiAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void KScreen::Output::maxBitsPerColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void KScreen::Output::edrPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void KScreen::Output::sharpnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void KScreen::Output::customModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void KScreen::Output::automaticBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void KScreen::Output::hdrIccProfilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void KScreen::Output::abmLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void KScreen::Output::modesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}
QT_WARNING_POP
