// This file was generated by qtwaylandscanner
// source file is kde-output-management-v2.xml

#include "qwayland-kde-output-management-v2.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    kde_output_management_v2::kde_output_management_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_output_management_v2::kde_output_management_v2(struct ::kde_output_management_v2 *obj)
        : m_kde_output_management_v2(obj)
    {
    }

    kde_output_management_v2::kde_output_management_v2()
        : m_kde_output_management_v2(nullptr)
    {
    }

    kde_output_management_v2::~kde_output_management_v2()
    {
    }

    void kde_output_management_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_output_management_v2 = static_cast<struct ::kde_output_management_v2 *>(wlRegistryBind(registry, id, &kde_output_management_v2_interface, version));
    }

    void kde_output_management_v2::init(struct ::kde_output_management_v2 *obj)
    {
        m_kde_output_management_v2 = obj;
    }

    kde_output_management_v2 *kde_output_management_v2::fromObject(struct ::kde_output_management_v2 *object)
    {
        return static_cast<kde_output_management_v2 *>(kde_output_management_v2_get_user_data(object));
    }

    bool kde_output_management_v2::isInitialized() const
    {
        return m_kde_output_management_v2 != nullptr;
    }

    uint32_t kde_output_management_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_output_management_v2));
    }

    const struct wl_interface *kde_output_management_v2::interface()
    {
        return &::kde_output_management_v2_interface;
    }

    struct ::kde_output_configuration_v2 *kde_output_management_v2::create_configuration()
    {
        struct ::kde_output_configuration_v2 * id = ::kde_output_management_v2_create_configuration(
            m_kde_output_management_v2);
        return id;
    }

    struct ::kde_mode_list_v2 *kde_output_management_v2::create_mode_list()
    {
        struct ::kde_mode_list_v2 * id = ::kde_output_management_v2_create_mode_list(
            m_kde_output_management_v2);
        return id;
    }

    kde_output_configuration_v2::kde_output_configuration_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_output_configuration_v2::kde_output_configuration_v2(struct ::kde_output_configuration_v2 *obj)
        : m_kde_output_configuration_v2(obj)
    {
        init_listener();
    }

    kde_output_configuration_v2::kde_output_configuration_v2()
        : m_kde_output_configuration_v2(nullptr)
    {
    }

    kde_output_configuration_v2::~kde_output_configuration_v2()
    {
    }

    void kde_output_configuration_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_output_configuration_v2 = static_cast<struct ::kde_output_configuration_v2 *>(wlRegistryBind(registry, id, &kde_output_configuration_v2_interface, version));
        init_listener();
    }

    void kde_output_configuration_v2::init(struct ::kde_output_configuration_v2 *obj)
    {
        m_kde_output_configuration_v2 = obj;
        init_listener();
    }

    kde_output_configuration_v2 *kde_output_configuration_v2::fromObject(struct ::kde_output_configuration_v2 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_kde_output_configuration_v2_listener)
            return nullptr;
        return static_cast<kde_output_configuration_v2 *>(kde_output_configuration_v2_get_user_data(object));
    }

    bool kde_output_configuration_v2::isInitialized() const
    {
        return m_kde_output_configuration_v2 != nullptr;
    }

    uint32_t kde_output_configuration_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_output_configuration_v2));
    }

    const struct wl_interface *kde_output_configuration_v2::interface()
    {
        return &::kde_output_configuration_v2_interface;
    }

    void kde_output_configuration_v2::enable(struct ::kde_output_device_v2 *outputdevice, int32_t enable)
    {
        ::kde_output_configuration_v2_enable(
            m_kde_output_configuration_v2,
            outputdevice,
            enable);
    }

    void kde_output_configuration_v2::mode(struct ::kde_output_device_v2 *outputdevice, struct ::kde_output_device_mode_v2 *mode)
    {
        ::kde_output_configuration_v2_mode(
            m_kde_output_configuration_v2,
            outputdevice,
            mode);
    }

    void kde_output_configuration_v2::transform(struct ::kde_output_device_v2 *outputdevice, int32_t transform)
    {
        ::kde_output_configuration_v2_transform(
            m_kde_output_configuration_v2,
            outputdevice,
            transform);
    }

    void kde_output_configuration_v2::position(struct ::kde_output_device_v2 *outputdevice, int32_t x, int32_t y)
    {
        ::kde_output_configuration_v2_position(
            m_kde_output_configuration_v2,
            outputdevice,
            x,
            y);
    }

    void kde_output_configuration_v2::scale(struct ::kde_output_device_v2 *outputdevice, wl_fixed_t scale)
    {
        ::kde_output_configuration_v2_scale(
            m_kde_output_configuration_v2,
            outputdevice,
            scale);
    }

    void kde_output_configuration_v2::apply()
    {
        ::kde_output_configuration_v2_apply(
            m_kde_output_configuration_v2);
    }

    void kde_output_configuration_v2::destroy()
    {
        ::kde_output_configuration_v2_destroy(
            m_kde_output_configuration_v2);
        m_kde_output_configuration_v2 = nullptr;
    }

    void kde_output_configuration_v2::overscan(struct ::kde_output_device_v2 *outputdevice, uint32_t overscan)
    {
        ::kde_output_configuration_v2_overscan(
            m_kde_output_configuration_v2,
            outputdevice,
            overscan);
    }

    void kde_output_configuration_v2::set_vrr_policy(struct ::kde_output_device_v2 *outputdevice, uint32_t policy)
    {
        ::kde_output_configuration_v2_set_vrr_policy(
            m_kde_output_configuration_v2,
            outputdevice,
            policy);
    }

    void kde_output_configuration_v2::set_rgb_range(struct ::kde_output_device_v2 *outputdevice, uint32_t rgb_range)
    {
        ::kde_output_configuration_v2_set_rgb_range(
            m_kde_output_configuration_v2,
            outputdevice,
            rgb_range);
    }

    void kde_output_configuration_v2::set_primary_output(struct ::kde_output_device_v2 *output)
    {
        ::kde_output_configuration_v2_set_primary_output(
            m_kde_output_configuration_v2,
            output);
    }

    void kde_output_configuration_v2::set_priority(struct ::kde_output_device_v2 *outputdevice, uint32_t priority)
    {
        ::kde_output_configuration_v2_set_priority(
            m_kde_output_configuration_v2,
            outputdevice,
            priority);
    }

    void kde_output_configuration_v2::set_high_dynamic_range(struct ::kde_output_device_v2 *outputdevice, uint32_t enable_hdr)
    {
        ::kde_output_configuration_v2_set_high_dynamic_range(
            m_kde_output_configuration_v2,
            outputdevice,
            enable_hdr);
    }

    void kde_output_configuration_v2::set_sdr_brightness(struct ::kde_output_device_v2 *outputdevice, uint32_t sdr_brightness)
    {
        ::kde_output_configuration_v2_set_sdr_brightness(
            m_kde_output_configuration_v2,
            outputdevice,
            sdr_brightness);
    }

    void kde_output_configuration_v2::set_wide_color_gamut(struct ::kde_output_device_v2 *outputdevice, uint32_t enable_wcg)
    {
        ::kde_output_configuration_v2_set_wide_color_gamut(
            m_kde_output_configuration_v2,
            outputdevice,
            enable_wcg);
    }

    void kde_output_configuration_v2::set_auto_rotate_policy(struct ::kde_output_device_v2 *outputdevice, uint32_t policy)
    {
        ::kde_output_configuration_v2_set_auto_rotate_policy(
            m_kde_output_configuration_v2,
            outputdevice,
            policy);
    }

    void kde_output_configuration_v2::set_icc_profile_path(struct ::kde_output_device_v2 *outputdevice, const QString &profile_path)
    {
        ::kde_output_configuration_v2_set_icc_profile_path(
            m_kde_output_configuration_v2,
            outputdevice,
            profile_path.toUtf8().constData());
    }

    void kde_output_configuration_v2::set_brightness_overrides(struct ::kde_output_device_v2 *outputdevice, int32_t max_peak_brightness, int32_t max_frame_average_brightness, int32_t min_brightness)
    {
        ::kde_output_configuration_v2_set_brightness_overrides(
            m_kde_output_configuration_v2,
            outputdevice,
            max_peak_brightness,
            max_frame_average_brightness,
            min_brightness);
    }

    void kde_output_configuration_v2::set_sdr_gamut_wideness(struct ::kde_output_device_v2 *outputdevice, uint32_t gamut_wideness)
    {
        ::kde_output_configuration_v2_set_sdr_gamut_wideness(
            m_kde_output_configuration_v2,
            outputdevice,
            gamut_wideness);
    }

    void kde_output_configuration_v2::set_color_profile_source(struct ::kde_output_device_v2 *outputdevice, uint32_t color_profile_source)
    {
        ::kde_output_configuration_v2_set_color_profile_source(
            m_kde_output_configuration_v2,
            outputdevice,
            color_profile_source);
    }

    void kde_output_configuration_v2::set_brightness(struct ::kde_output_device_v2 *outputdevice, uint32_t brightness)
    {
        ::kde_output_configuration_v2_set_brightness(
            m_kde_output_configuration_v2,
            outputdevice,
            brightness);
    }

    void kde_output_configuration_v2::set_color_power_tradeoff(struct ::kde_output_device_v2 *outputdevice, uint32_t preference)
    {
        ::kde_output_configuration_v2_set_color_power_tradeoff(
            m_kde_output_configuration_v2,
            outputdevice,
            preference);
    }

    void kde_output_configuration_v2::set_dimming(struct ::kde_output_device_v2 *outputdevice, uint32_t multiplier)
    {
        ::kde_output_configuration_v2_set_dimming(
            m_kde_output_configuration_v2,
            outputdevice,
            multiplier);
    }

    void kde_output_configuration_v2::set_replication_source(struct ::kde_output_device_v2 *outputdevice, const QString &source)
    {
        ::kde_output_configuration_v2_set_replication_source(
            m_kde_output_configuration_v2,
            outputdevice,
            source.toUtf8().constData());
    }

    void kde_output_configuration_v2::set_ddc_ci_allowed(struct ::kde_output_device_v2 *outputdevice, uint32_t allowed)
    {
        ::kde_output_configuration_v2_set_ddc_ci_allowed(
            m_kde_output_configuration_v2,
            outputdevice,
            allowed);
    }

    void kde_output_configuration_v2::set_max_bits_per_color(struct ::kde_output_device_v2 *outputdevice, uint32_t max_bpc)
    {
        ::kde_output_configuration_v2_set_max_bits_per_color(
            m_kde_output_configuration_v2,
            outputdevice,
            max_bpc);
    }

    void kde_output_configuration_v2::set_edr_policy(struct ::kde_output_device_v2 *outputdevice, uint32_t policy)
    {
        ::kde_output_configuration_v2_set_edr_policy(
            m_kde_output_configuration_v2,
            outputdevice,
            policy);
    }

    void kde_output_configuration_v2::set_sharpness(struct ::kde_output_device_v2 *outputdevice, uint32_t sharpness)
    {
        ::kde_output_configuration_v2_set_sharpness(
            m_kde_output_configuration_v2,
            outputdevice,
            sharpness);
    }

    void kde_output_configuration_v2::set_custom_modes(struct ::kde_output_device_v2 *outputdevice, struct ::kde_mode_list_v2 *modes)
    {
        ::kde_output_configuration_v2_set_custom_modes(
            m_kde_output_configuration_v2,
            outputdevice,
            modes);
    }

    void kde_output_configuration_v2::set_auto_brightness(struct ::kde_output_device_v2 *outputdevice, uint32_t enabled)
    {
        ::kde_output_configuration_v2_set_auto_brightness(
            m_kde_output_configuration_v2,
            outputdevice,
            enabled);
    }

    void kde_output_configuration_v2::set_hdr_icc_profile_path(struct ::kde_output_device_v2 *outputdevice, const QString &profile_path)
    {
        ::kde_output_configuration_v2_set_hdr_icc_profile_path(
            m_kde_output_configuration_v2,
            outputdevice,
            profile_path.toUtf8().constData());
    }

    void kde_output_configuration_v2::set_hdr_color_profile_source(struct ::kde_output_device_v2 *outputdevice, uint32_t color_profile_source)
    {
        ::kde_output_configuration_v2_set_hdr_color_profile_source(
            m_kde_output_configuration_v2,
            outputdevice,
            color_profile_source);
    }

    void kde_output_configuration_v2::set_abm_level(struct ::kde_output_device_v2 *outputdevice, uint32_t level)
    {
        ::kde_output_configuration_v2_set_abm_level(
            m_kde_output_configuration_v2,
            outputdevice,
            level);
    }

    void kde_output_configuration_v2::kde_output_configuration_v2_applied()
    {
    }

    void kde_output_configuration_v2::handle_applied(
        void *data,
        struct ::kde_output_configuration_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_configuration_v2 *>(data)->kde_output_configuration_v2_applied();
    }

    void kde_output_configuration_v2::kde_output_configuration_v2_failed()
    {
    }

    void kde_output_configuration_v2::handle_failed(
        void *data,
        struct ::kde_output_configuration_v2 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_configuration_v2 *>(data)->kde_output_configuration_v2_failed();
    }

    void kde_output_configuration_v2::kde_output_configuration_v2_failure_reason(const QString &)
    {
    }

    void kde_output_configuration_v2::handle_failure_reason(
        void *data,
        struct ::kde_output_configuration_v2 *object,
        const char *reason)
    {
        Q_UNUSED(object);
        static_cast<kde_output_configuration_v2 *>(data)->kde_output_configuration_v2_failure_reason(
            QString::fromUtf8(reason));
    }

    const struct kde_output_configuration_v2_listener kde_output_configuration_v2::m_kde_output_configuration_v2_listener = {
        kde_output_configuration_v2::handle_applied,
        kde_output_configuration_v2::handle_failed,
        kde_output_configuration_v2::handle_failure_reason,
    };

    void kde_output_configuration_v2::init_listener()
    {
        kde_output_configuration_v2_add_listener(m_kde_output_configuration_v2, &m_kde_output_configuration_v2_listener, this);
    }

    kde_mode_list_v2::kde_mode_list_v2(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    kde_mode_list_v2::kde_mode_list_v2(struct ::kde_mode_list_v2 *obj)
        : m_kde_mode_list_v2(obj)
    {
    }

    kde_mode_list_v2::kde_mode_list_v2()
        : m_kde_mode_list_v2(nullptr)
    {
    }

    kde_mode_list_v2::~kde_mode_list_v2()
    {
    }

    void kde_mode_list_v2::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_kde_mode_list_v2 = static_cast<struct ::kde_mode_list_v2 *>(wlRegistryBind(registry, id, &kde_mode_list_v2_interface, version));
    }

    void kde_mode_list_v2::init(struct ::kde_mode_list_v2 *obj)
    {
        m_kde_mode_list_v2 = obj;
    }

    kde_mode_list_v2 *kde_mode_list_v2::fromObject(struct ::kde_mode_list_v2 *object)
    {
        return static_cast<kde_mode_list_v2 *>(kde_mode_list_v2_get_user_data(object));
    }

    bool kde_mode_list_v2::isInitialized() const
    {
        return m_kde_mode_list_v2 != nullptr;
    }

    uint32_t kde_mode_list_v2::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_kde_mode_list_v2));
    }

    const struct wl_interface *kde_mode_list_v2::interface()
    {
        return &::kde_mode_list_v2_interface;
    }

    void kde_mode_list_v2::destroy()
    {
        ::kde_mode_list_v2_destroy(
            m_kde_mode_list_v2);
        m_kde_mode_list_v2 = nullptr;
    }

    void kde_mode_list_v2::add_mode()
    {
        ::kde_mode_list_v2_add_mode(
            m_kde_mode_list_v2);
    }

    void kde_mode_list_v2::set_resolution(uint32_t width, uint32_t height)
    {
        ::kde_mode_list_v2_set_resolution(
            m_kde_mode_list_v2,
            width,
            height);
    }

    void kde_mode_list_v2::set_refresh_rate(uint32_t rate)
    {
        ::kde_mode_list_v2_set_refresh_rate(
            m_kde_mode_list_v2,
            rate);
    }

    void kde_mode_list_v2::set_reduced_blanking(uint32_t reduced)
    {
        ::kde_mode_list_v2_set_reduced_blanking(
            m_kde_mode_list_v2,
            reduced);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
